import React, { useState, useEffect } from 'react'
import { translate } from 'cozy-ui/react/I18n'
import { EcogestureType } from 'services/dataChallengeContracts'
import StyledEcogestureCard from 'components/CommonKit/Card/StyledEcogestureCard'
import Icon from 'cozy-ui/react/Icon'
import def from 'assets/icons/visu/ecogesture/default.svg'

interface EcogestureCardProps {
  ecogesture: EcogestureType
  handleClick?: (ecogesture: EcogestureType) => void
  t: Function
  challengeEcogesture?: number
}

const EcogestureCard: React.FC<EcogestureCardProps> = ({
  ecogesture,
  handleClick,
  t,
  challengeEcogesture,
}: EcogestureCardProps) => {
  const handleCardclick = () => {
    handleClick && ecogesture ? handleClick(ecogesture) : null
  }
  const [ecogestureIcon, setEcogestureIcon] = useState(def)

  async function importEcogestureIcon(id: string) {
    // Les svg doivent être au format id.svg
    let importedEcogesture
    try {
      importedEcogesture = await import(
        /* webpackMode: "eager" */ `assets/icons/visu/ecogesture/${id}.svg`
      )
    } catch (e) {}
    if (importedEcogesture) {
      setEcogestureIcon(importedEcogesture.default)
    }
  }

  useEffect(() => {
    if (ecogesture) {
      importEcogestureIcon(ecogesture.id)
    }
  }, [])

  return (
    <>
      {challengeEcogesture ? (
        <div className={`cp-eg-${challengeEcogesture}`}>
          <StyledEcogestureCard border={true} onClick={handleCardclick}>
            <div className="ec">
              <div className="ec-content ec-content-challenge">
                <div>
                  <Icon className="Icon" icon={ecogestureIcon} size={64} />
                </div>
                <div className="ec-content-challenge-text">
                  {ecogesture.shortName}
                </div>
              </div>
            </div>
          </StyledEcogestureCard>
        </div>
      ) : (
        <StyledEcogestureCard
          unlocked={ecogesture.unlocked ? ecogesture.unlocked : false}
          onClick={handleCardclick}
        >
          <div className="ec">
            <div
              className={`ec-content ${
                ecogesture.unlocked ? 'ec-content-unlocked' : ''
              }`}
            >
              <div className="ec-content-icon">
                {ecogesture.unlocked && (
                  <Icon className="Icon" icon={ecogestureIcon} size={50} />
                )}
              </div>
              <div className="ec-content-short-name text-16-bold">
                {ecogesture.shortName}
              </div>
              <div className="ec-content-nwh">
                <span className="text-16-bold">{ecogesture.nwh}</span>
                <span className="text-16-normal"> nWh</span>
              </div>
            </div>
          </div>
        </StyledEcogestureCard>
      )}
    </>
  )
}

export default translate()(EcogestureCard)
