import React from 'react'
import { translate } from 'cozy-ui/react/I18n'

import IFluidConfig from 'services/IFluidConfig'
import { Konnector, Trigger } from 'doctypes'

import KonnectorLoginForm from 'components/ContentComponents/Konnector/KonnectorLoginForm'
import KonnectorOAuthForm from 'components/ContentComponents/Konnector/KonnectorOAuthForm'

interface KonnectorFormProps {
  fluidConfig: IFluidConfig
  konnector: Konnector
  account: Account | null
  trigger: Trigger | null
  handleSuccessForm: Function
}

const KonnectorForm: React.FC<KonnectorFormProps> = ({
  fluidConfig,
  konnector,
  account,
  trigger,
  handleSuccessForm,
}: KonnectorFormProps) => {
  const oAuth: boolean = fluidConfig.konnectorConfig.oauth

  const handleSuccess = (_account: Account, _trigger: Trigger) => {
    handleSuccessForm(_account, _trigger)
  }

  return (
    <>
      {!oAuth ? (
        <KonnectorLoginForm
          fluidConfig={fluidConfig}
          onSuccess={handleSuccess}
          account={account}
          trigger={trigger}
        />
      ) : (
        <KonnectorOAuthForm
          konnector={konnector}
          siteLink={fluidConfig.siteLink}
          onSuccess={handleSuccess}
        />
      )}
    </>
  )
}

export default translate()(KonnectorForm)
